/****************************************************************/
/*                                                              */
/*          S A S   I N S T A L L A T I O N   T E S T           */
/*                                                              */
/*    NAME: TSTHPFST                                            */
/*   TITLE: INSTALLATION TEST FOR PROC HPFOREST                 */
/* PRODUCT: HPA                                                 */
/*  SYSTEM:                                                     */
/*    KEYS:                                                     */
/*   PROCS: HPFOREST, DATA STEP                                 */
/*    DATA:                                                     */
/*                                                              */
/* SUPPORT:                                                     */
/*  UPDATE:                                                     */
/*     REF:                                                     */
/*    MISC:                                                     */
/*                                                              */
/****************************************************************/


%macro check(data1,data2,opts,drop);

proc compare base=&data1(label='' &drop)
             compare=&data2(label='' &drop)
             outstats=check nosummary &opts;
    attrib _all_ format = label = '';
run;

%rccheck(&sysinfo,0);

%mend;

data val;
    do id=1 to 100;
        vb =ceil(ranuni(2019615)*2);
        vn =ceil(ranuni(6403210)*5);
        vo =ceil(ranuni(1234567)*5);
        v2 =ceil(ranuni(6806290)*4);
        v3 =ceil(ranuni(9602140)*5);
        v4 =ceil(ranuni(1041726)*6);
        v5 =ceil(ranuni(1234567)*5);
        v6 =ceil(ranuni(5432100)*4);
        v7 =v5 / (v6+1) + log10(1234+v4) - 20;
        v8 =v2 / v6 + log(12345+v3) - 30;
        v9 =v3 / v5;
        v10=v4 / sqrt(v6+5) + (v2*v5+1);
        v11=v2 / sqrt(v3+2) + log(v4*v6+1);
        vi =v2 / sqrt(v4+1) + rannor(98765);
        freq=ceil(ranuni(2019615)*10);
        output;
    end;
run;

 *- SMP MODE -*;
proc HPFOREST data=val maxtrees=10;
    ods output NObs=NObs_SMP
               FitStatistics=FitStatistics_SMP
               ModelInfo=ModelInfo_SMP;
    input v2-v6/level=nominal;
    input v7-v11/level=interval;
    target vn/level=nominal;
    id id;
    freq freq;
    score out=score_out1;
quit;

 *- MPP MODE -*;
proc HPFOREST data=val maxtrees=10;
    ods output NObs=NObs_MPP
               FitStatistics=FitStatistics_MPP
               ModelInfo=ModelInfo_MPP;
    input v2-v6/level=nominal;
    input v7-v11/level=interval;
    target vn/level=nominal;
    id id;
    freq freq;
    score out=score_out2;
    performance &PERFORMANCE_OPTS;
quit;


/* expected output for NObs */
data NObs(LABEL=Number of Observations);
    format N BEST12.8;
    length Type $ 27;
    input Type $ 1-27 N;
datalines;
Number of Observations Read             100
Number of Observations Used             100
;

%check(NObs,NObs_SMP,,%str(drop=type));
%check(NObs,NObs_MPP,,%str(drop=type));

/* expected output for Model information */
data ModelInfo(LABEL=Model Information);
    label Setting="Value";
    format Setting BEST12.8;
    length Parameter $ 22 Default $ 11;
    input Parameter $ 1-22 Setting Default $ 43-53;
datalines;
Category Bins                       30    (Default)
Leaf Size                            5    (Default)
Maximum Depth                       50    (Default)
Maximum Trees                       10
Minimum Category Size                5    (Default)
Variables to Try                     3    (Default)
Alpha                             0.05    (Default)
Exhaustive                        5000    (Default)
Leaf Fraction                    0.001    (Default)
Train Fraction                     0.6    (Default)
Split Criterion                      2    Gini
Missing Value Handling               1    Valid value
;

%check(ModelInfo,ModelInfo_SMP,,%str(drop=Parameter Default));
%check(ModelInfo,ModelInfo_MPP,,%str(drop=Parameter Default));

/* expected output for Fit statistics */
data FitStatistics(LABEL=Fit Statistics);
    format NTrees 4. NLeaves 7. PredAll PredOob MiscAll MiscOob D12.3;
    length PredAll PredOob MiscAll MiscOob 8;
    input NTrees  NLeaves PredAll PredOob MiscAll MiscOob;
datalines;
    1         8      0.150447      0.195116      0.565302      0.703704
    2        16      0.130017      0.190001      0.539961      0.697947
    3        22      0.129243      0.174016      0.493177      0.650754
    4        30      0.126728      0.178734      0.497076      0.675615
    5        38      0.125662      0.176839      0.536062      0.689583
    6        45      0.123110      0.174159      0.438596      0.721311
    7        51      0.122865      0.169396      0.458090      0.728000
    8        59      0.121224      0.166296      0.426901      0.710059
    9        65      0.120718      0.162515      0.399610      0.723197
   10        73      0.120265      0.166876      0.370370      0.746589
;

%check(FitStatistics,FitStatistics_SMP,%str(method=absolute criterion=.0001));