/****************************************************************/
/*                                                              */
/*          S A S   I N S T A L L A T I O N   T E S T           */
/*                                                              */
/*    NAME: TSTHPNEU                                            */
/*   TITLE: INSTALLATION TEST FOR PROC HPNEURAL                 */
/* PRODUCT: HPA                                                 */
/*  SYSTEM:                                                     */
/*    KEYS:                                                     */
/*   PROCS: HPNEURAL, DATA STEP                                 */
/*    DATA:                                                     */
/*                                                              */
/* SUPPORT:                                                     */
/*  UPDATE:                                                     */
/*     REF:                                                     */
/*    MISC:                                                     */
/*                                                              */
/****************************************************************/


%macro check(data1,data2,opts,drop);

proc compare base=&data1(label='' &drop)
             compare=&data2(label='' &drop)
             outstats=check nosummary &opts;
    attrib _all_ format = label = '';
run;

%rccheck(&sysinfo,0);

%mend;


data matrix;
    input x1-x3;
datalines;
0 1 1
1 0 1
0 0 0
1 1 0
;

 *- SMP MODE -*;
proc hpneural data=matrix;
    ods output Nobs=Nobs_SMP
        ErrorSummary=ErrorSummary_SMP
        Training=Training_SMP
        Iteration=Iteration_SMP;
    input  x1-x2;
    hidden 2;
    target x3;
    train numtries=5 valid=_none_;
    score out=xoscores_SMP;
run;

 *- MPP MODE -*;
proc hpneural data=matrix;
    ods output Nobs=Nobs_MPP
        ErrorSummary=ErrorSummary_MPP
        Training=Training_MPP
        Iteration=Iteration_MPP;
    input  x1-x2;
    hidden 2;
    target x3;
    train numtries=5 valid=_none_;
    score out=xoscores_MPP;
    performance &PERFORMANCE_OPTS;
run;

/* expected output */

data NObs(label='Number of Observations');
    length label $ 27;
    input label $ 1-27 N NObsRead NObsUsed SumFreqsRead SumFreqsUsed;
datalines;
Number of Observations Read   4  4  4  4  4
Number of Observations Used   4  4  4  4  4
Number Used for Training      4  0  0  0  0
Number Used for Validation    0  0  0  0  0
;

%check(NObs_SMP,NObs,
  %str(method=absolute criterion=.0001),%str(drop=label));
%check(NObs_MPP,NObs,
  %str(method=absolute criterion=.0001),%str(drop=label));

/* expected output */
data ErrorSummary(label='Error Summary for x3');
    format Value percent10.5;
    input Description $1-15  Value;
datalines;
% Average Error  0.0032025
% Maximum Error  0.0045999
;

%check(ErrorSummary_SMP,ErrorSummary,
  %str(method=absolute criterion=.0001),%str(drop=Description));
%check(ErrorSummary_MPP,ErrorSummary,
  %str(method=absolute criterion=.0001),%str(drop=Description));

/* expected output */
data Training(label='Training Table');
    input TryNum NumIterations TrainingError
          ValidationError StoppingReason $22-35 Best $39;
datalines;
 1  30  0.002873  .  Training Error   Y
 2  35  0.287258  .  Training Error
 3  29  0.282850  .  Training Error
 4  50  0.003727  .  Training Error
 5  26  0.282845  .  Training Error
;

%check(Training_SMP,Training,
  %str(method=absolute criterion=.0001),%str(drop=StoppingReason Best));
%check(Training_MPP,Training,
  %str(method=absolute criterion=.0001),%str(drop=StoppingReason Best));

/* expected output */
data Iteration(label='Iteration Table');
    input IterationNum TrainingError ValidationError Best $20;
datalines;
 0  0.403099   .
 1  0.400089   .
 2  0.400057   .
 3  0.400045   .
 4  0.399995   .
 5  0.399976   .
 6  0.399961   .
 7  0.394650   .
 8  0.394638   .
 9  0.379675   .
10  0.320163   .
11  0.309553   .
12  0.294021   .
13  0.289380   .
14  0.287528   .
15  0.287005   .
16  0.286910   .
17  0.286893   .
18  0.286882   .
19  0.286844   .
20  0.197039   .
21  0.197037   .
22  0.195041   .
23  0.186793   .
24  0.178165   .
25  0.140514   .
26  0.063334   .
27  0.034872   .
28  0.016510   .
29  0.007035   .
30  0.002873   .   Y
;

%check(Iteration_SMP,Iteration,
  %str(method=absolute criterion=.0001),%str(drop=best));
%check(Iteration_MPP,Iteration,
  %str(method=absolute criterion=.0001),%str(drop=best));

/* expected output */
data xoscores(label='xoscores Table');
    input x3  P_x3;
datalines;
 1   0.9965800000
 1   1.0043000000
 0   0.0046000000
 0   0.0004900000
;

%check(xoscores_SMP,xoscores,
       %str(method=absolute criterion=0.0001));
%check(xoscores_MPP,xoscores,
       %str(method=absolute criterion=0.0001));















