/****************************************************************/
/*                                                              */
/*          S A S   I N S T A L L A T I O N   T E S T           */
/*                                                              */
/*    NAME: TSTHPRED                                            */
/*   TITLE: INSTALLATION TEST FOR PROC HPREDUCE                 */
/* PRODUCT: HPA                                                 */
/*  SYSTEM:                                                     */
/*    KEYS:                                                     */
/*   PROCS: HPREDUCE, DATA STEP                                 */
/*    DATA:                                                     */
/*                                                              */
/* SUPPORT:                                                     */
/*  UPDATE:                                                     */
/*     REF:                                                     */
/*    MISC:                                                     */
/*                                                              */
/****************************************************************/


%macro check(data1,data2,opts,drop);

proc compare base=&data1(label='' &drop)
             compare=&data2(label='' &drop)
             outstats=check nosummary &opts;
    attrib _all_ format = label = '';
run;

%rccheck(&sysinfo,0);

%mend;

data one;
    array x{10};
    array c{10};
    do i=1 to 500;
        do j=1 to 10;
           x{j} = ranuni(1);
           c{j} = 100 + int(ranuni(1)*4);
        end;
        y = int(ranuni(1)*2);
        output;
    end;
run;

 *- SMP MODE -*;
proc HPREDUCE data=one outcp=OutPearson1;
    ods output ModelInfo = ModelInfo_SMP
                    Nobs = Nobs_SMP
             ClassLevels = ClassLevels_SMP
        SelectionSummary = SelectionSummary_SMP
         SelectedEffects = SelectedEffects_SMP;
    class c1 c2 c3;
    reduce unsupervised c1 x1 x2 c2 / maxsteps=10;
run;

 *- MPP MODE -*;
proc HPREDUCE data=one outcp=OutPearson1;
    ods output ModelInfo = ModelInfo_MPP
                    Nobs = Nobs_MPP
             ClassLevels = ClassLevels_MPP
        SelectionSummary = SelectionSummary_MPP
         SelectedEffects = SelectedEffects_MPP;
    class c1 c2 c3;
    reduce unsupervised c1 x1 x2 c2 / maxsteps=10;
    performance &PERFORMANCE_OPTS;
run;


/* expected output */

data NObs2(label='Number of Observations');
    length label $ 27;
    input label $ 1-27 N NObsRead NObsUsed SumFreqsRead SumFreqsUsed;
datalines;
Number of Observations Read  500  500  500  500  500
Number of Observations Used  500  500  500  500  500
;

%check(NObs_SMP,NObs2,
  %str(method=absolute criterion=.0001),%str(drop=label));
%check(NObs_MPP,NObs2,
  %str(method=absolute criterion=.0001),%str(drop=label));


/* expected output */

/* Model Information table contains only character variables  */

data ModelInfo2(label='Model Information');
    length Descr $ 23 Value $ 17;
    input Descr $ 1-23 Value $ 26-42;
datalines;
Data Source              WORK.ONE
Model Type               Unsupervised
Class Parameterization   GLM
Selection Technique      Variance Analysis
Number of Variables      4
Maximal Number of Steps  10
;

/*
%check(ModelInfo_SMP,ModelInfo2,
  %str(method=absolute criterion=.0001),%str(drop=Descr Value));
%check(ModelInfo_MPP,ModelInfo2,
  %str(method=absolute criterion=.0001),%str(drop=Descr Value));
*/

/* expected output */
data ClassLevels2(label='Class Level Information');
    length class $ 2 values $ 16;
    input class $ Levels values $ 19-33;
datalines;
c1           4    100 101 102 103
c2           4    100 101 102 103
c3           4    100 101 102 103
;

%check(ClassLevels_SMP,Classlevels2,
  %str(method=absolute criterion=.0001),%str(drop=class));
%check(ClassLevels_MPP,Classlevels2,
  %str(method=absolute criterion=.0001),%str(drop=class));

/* expected output */
data SelectionSummary2(label='Selection Summary');
    length Variable $ 2 Level $ 3;
    input Iteration Variable $ Level $ VarExp;
datalines;
1         c1        103     0.1383
2         c2        101     0.2751
3         c2        103     0.4099
4         c1        102      0.542
5         c2        100     0.6725
6         c1        100     0.8016
7         x1         .-     0.9014
8         x2         .-          1
;

%check(SelectionSummary_SMP,SelectionSummary2,
  %str(method=absolute criterion=.0001),%str(drop=Level));
%check(SelectionSummary_MPP,SelectionSummary2,
  %str(method=absolute criterion=.0001),%str(drop=Level));


/* expected output */
data SelectedEffects2(label='Selected Effects');
    length Variable $ 2 Type $ 8;
    input Number Variable $ Type $;
datalines;
1       c1       CLASS
2       c2       CLASS
3       x1       INTERVAL
4       x2       INTERVAL
;

%check(SelectedEffects_SMP,SelectedEffects2,
  %str(method=absolute criterion=.0001),%str(drop=Type));
%check(SelectedEffects_MPP,SelectedEffects2,
  %str(method=absolute criterion=.0001),%str(drop=Type));