/****************************************************************/
/*                                                              */
/*          S A S   I N S T A L L A T I O N   T E S T           */
/*                                                              */
/*    NAME: TSTHPREG                                            */
/*   TITLE: INSTALLATION TEST FOR PROC HPREG                    */
/* PRODUCT: HPA                                                 */
/*  SYSTEM:                                                     */
/*    KEYS:                                                     */
/*   PROCS: HPREG, DATA STEP                                    */
/*    DATA:                                                     */
/*                                                              */
/* SUPPORT:                                                     */
/*  UPDATE:                                                     */
/*     REF:                                                     */
/*    MISC:                                                     */
/*                                                              */
/****************************************************************/


%macro check(data1,data2,opts,drop);

proc compare base=&data1(label='' &drop)
             compare=&data2(label='' &drop)
             outstats=check nosummary &opts;
    attrib _all_ format = label = '';
run;

%rccheck(&sysinfo,0);

%mend;


data neuralgia;
   length Pain $ 2;
   input Treatment $ Sex $ Age Duration Pain $ @@;
datalines;
A  M  71  17   P     A  F  63  27  PF    A  F  69  18   P
P  F  68   1  PF     B  M  74  16  PF    P  F  67  30  PF
P  M  66  26   P     B  F  67  28  PF    B  F  77  16  PF
A  F  71  12  PF     B  F  72  50  PF    B  F  76   9   P
B  F  66  12  PF     A  M  62  42  PF    P  F  64   1   P
A  F  64  17  PF     P  M  74   4  PF    A  F  72  25  PF
P  M  70   1   P     B  M  66  19  PF    B  M  59  29  PF
A  F  64  30  PF     A  M  70  28  PF    A  M  69   1  PF
B  F  78   1  PF     P  M  83   1   P    B  F  69  42  PF
B  M  75  30   P     P  M  77  29   P    P  F  79  20   P
A  M  70  12  PF     A  F  69  12  PF    B  F  65  14  PF
B  M  70   1  PF     B  M  67  23  PF    A  M  76  25   P
P  M  78  12   P     B  M  77   1   P    B  F  69  24  PF
P  M  66   4   P     P  F  65  29  PF    P  M  60  26   P
A  M  78  15   P     B  M  75  21   P    A  F  67  11  PF
P  F  72  27  PF     P  F  70  13   P    A  M  75   6   P
B  F  65   7  PF     P  F  68  27   P    P  M  68  11   P
P  M  67  17   P     B  M  70  22  PF    A  M  65  15  PF
P  F  67   1   P     A  M  67  10  PF    P  F  72  11   P
A  F  74   1  PF     B  M  80  21   P    A  F  69   3  PF
;

 *- SMP MODE -*;
proc hpreg data=neuralgia;
    ods output NObs=NObs_SMP
            ClassLevels=ClassLevels_SMP
            Dimensions=Dimensions_SMP
            ANOVA=ANOVA_SMP
            FitStatistics=FitStatistics_SMP
            ParameterEstimates=ParameterEstimates_SMP;
    class treatment sex pain;
    model duration = pain sex treatment;
run;

 *- MPP MODE -*;
proc hpreg data=neuralgia;
    ods output NObs=NObs_MPP
            ClassLevels=ClassLevels_MPP
            Dimensions=Dimensions_MPP
            ANOVA=ANOVA_MPP
            FitStatistics=FitStatistics_MPP
            ParameterEstimates=ParameterEstimates_MPP;
    class treatment sex pain;
    model duration = pain sex treatment;
    performance &PERFORMANCE_OPTS;
run;

/* expected output for NObs */
data NObs2(label='Number of Observations');
    length label $ 27;
    input label $ 1-27 N NObsRead NObsUsed;
datalines;
Number of Observations Read    60    60     60
Number of Observations Used    60    60     60
;

%check(NObs_SMP,NObs2,
  %str(method=absolute criterion=.0001),%str(drop=label));
%check(NObs_MPP,NObs2,
  %str(method=absolute criterion=.0001),%str(drop=label));

/* expected output ClassLevels */
data ClassLevels2(label='Class Level Information');
    length class $ 9 values $ 6;
    input Class $ Levels Values $ 24-28;
datalines;
treatment         3    A B P
sex               2    F M
pain              2    P PF
;

%check(ClassLevels_SMP,Classlevels2,
  %str(method=absolute criterion=.0001),%str(drop=class));
%check(ClassLevels_MPP,Classlevels2,
  %str(method=absolute criterion=.0001),%str(drop=class));

/* expected output */
data Dimensions2(label='Dimensions');
    length Description $ 20;
    input Description $ 1-20 Value;
datalines;
Number of Effects              4
Number of Parameters           8
;

%check(Dimensions_SMP,Dimensions2,
  %str(method=absolute criterion=.0001),%str(drop=Description));
%check(Dimensions_MPP,Dimensions2,
  %str(method=absolute criterion=.0001),%str(drop=Description));

/* expected output */
data ANOVA2(label='ANOVA');
    length Source $ 15;
    input Source $ 1-15 DF SS MS FValue ProbF;
datalines;
Model              4     330.77071      82.69268      0.5963   0.6668
Error             55    7626.96263     138.67205          ._       ._
Corrected Total   59    7957.73333            ._          ._       ._
;

%check(ANOVA_SMP, ANOVA2,
  %str(method=absolute criterion=.0001),%str(drop=Source));
%check(ANOVA_MPP, ANOVA2,
  %str(method=absolute criterion=.0001),%str(drop=Source));

/* expected output */
data FitStatistics2(label='Fit Statistics');
    length Label $ 8;
    input Label $ 1-8 Value;
datalines;
Root MSE       11.77591
R-Square        0.04157
Adj R-Sq       -0.02814
AIC           362.70602
AICC          364.29093
SBC           311.17775
ASE           127.11604
;

%check(FitStatistics_SMP,FitStatistics2,
  %str(method=absolute criterion=.0001),%str(drop=Label));
%check(FitStatistics_MPP,FitStatistics2,
  %str(method=absolute criterion=.0001),%str(drop=Label));

/* expected output */
data ParameterEstimates2(label='Parameter Estimates');
    length effect $ 9 parameter $ 11 pain $ 2 sex treatment $ 1;
    input Effect $ pain $ 11-12 treatment $ 14 sex $ 16
       Parameter $ 18-28 DF Estimate StandardizedEst Stderr
       tValue Probt;
datalines;
Intercept        Intercept   1 16.565152  0.00000 4.537697  3.6505633 0.0005837
pain      P      pain P      1 -2.868687 -0.12281 3.742630 -0.7664896 0.4466625
pain      PF     pain PF     0         0  0.00000        .   .         .
sex            F sex F       1  0.272727  0.01184 3.241212  0.0841436 0.9332478
sex            M sex M       0         0  0.00000        .   .         .
treatment    A   treatment A 1  0.365657  0.01497 4.167616  0.0877376 0.9304039
treatment    B   treatment B 1  3.315657  0.13572 4.167616  0.7955763 0.4296986
treatment    P   treatment P 0         0  0.00000        .   .         .
;

%check(ParameterEstimates_SMP,ParameterEstimates2,
  %str(method=absolute criterion=.0001),
  %str(drop=Effect pain treatment sex parameter));
%check(ParameterEstimates_MPP,ParameterEstimates2,
  %str(method=absolute criterion=.0001),
  %str(drop=Effect pain treatment sex parameter));