/****************************************************************/
/*                                                              */
/*          S A S   I N S T A L L A T I O N   T E S T           */
/*                                                              */
/*    NAME: TSTHPSAM                                            */
/*   TITLE: INSTALLATION TEST FOR PROC HPSAMPLE                 */
/* PRODUCT: HPA                                                 */
/*  SYSTEM:                                                     */
/*    KEYS:                                                     */
/*   PROCS: HPSAMPLE, DATA STEP                                 */
/*    DATA:                                                     */
/*                                                              */
/* SUPPORT:                                                     */
/*  UPDATE:                                                     */
/*     REF:                                                     */
/*    MISC:                                                     */
/*                                                              */
/****************************************************************/

%macro check(data1,data2,opts,drop);

proc compare base=&data1(label='' &drop)
             compare=&data2(label='' &drop)
             outstats=check nosummary &opts warning;
    attrib _all_ format = label = '';
run;

%rccheck(&sysinfo,0);

%mend;

data neuralgia;
   length Pain $ 2;
   input Treatment $ Sex $ Age Duration Pain $ @@;
datalines;
A  M  71  17   P     A  F  63  27  PF    A  F  69  18   P
P  F  68   1  PF     B  M  74  16  PF    P  F  67  30  PF
P  M  66  26   P     B  F  67  28  PF    B  F  77  16  PF
A  F  71  12  PF     B  F  72  50  PF    B  F  76   9   P
B  F  66  12  PF     A  M  62  42  PF    P  F  64   1   P
A  F  64  17  PF     P  M  74   4  PF    A  F  72  25  PF
P  M  70   1   P     B  M  66  19  PF    B  M  59  29  PF
A  F  64  30  PF     A  M  70  28  PF    A  M  69   1  PF
B  F  78   1  PF     P  M  83   1   P    B  F  69  42  PF
B  M  75  30   P     P  M  77  29   P    P  F  79  20   P
A  M  70  12  PF     A  F  69  12  PF    B  F  65  14  PF
B  M  70   1  PF     B  M  67  23  PF    A  M  76  25   P
P  M  78  12   P     B  M  77   1   P    B  F  69  24  PF
P  M  66   4   P     P  F  65  29  PF    P  M  60  26   P
A  M  78  15   P     B  M  75  21   P    A  F  67  11  PF
P  F  72  27  PF     P  F  70  13   P    A  M  75   6   P
B  F  65   7  PF     P  F  68  27   P    P  M  68  11   P
P  M  67  17   P     B  M  70  22  PF    A  M  65  15  PF
P  F  67   1   P     A  M  67  10  PF    P  F  72  11   P
A  F  74   1  PF     B  M  80  21   P    A  F  69   3  PF
;

%macro test();

%let notes=%sysfunc(getoption(notes));
options nonotes;
%do i = 1 %to 9;
    data neuralgia;
        set neuralgia neuralgia;
    run;
%end;
options &notes;
%mend;

%test;


 *- SMP MODE -*;
proc hpsample data=neuralgia out=samp_solo sampobs=500 seed=12345;
    ods output freqtable=freq_s;
    class treatment sex pain;
    var age duration ;
    target sex;
run;

 *- MPP MODE -*;
proc hpsample data=neuralgia out=samp_grid sampobs=500 seed=12345;
    ods output freqtable=freq_g;
    class treatment sex pain;
    var age duration ;
    target sex;
    performance &PERFORMANCE_OPTS;
run;

data freq;
    length target $1;
    input target $ nobs nsamp;
datalines;
F  15360  256
M  15360  256
;

%check(freq,freq_g,%str(method=relative criterion=10));
%check(freq,freq_s,%str(method=relative criterion=10));